import { ElementRef, TemplateRef } from '@angular/core';
import { TableController, VirtualScrollComponent } from '@lightweightform/core';
import { BsActionsMenuAction } from '../../actions-menu/actions-menu.component';
import { FieldComponentCommon } from '../create-field-component';
import { TableHeaderComponent } from './table-header/table-header.component';
/**
 * Key used to translate the "add row" text of the table component.
 */
export declare const I18N_TABLE_ADD_ROW_KEY = "BS_TABLE_ADD_ROW";
/**
 * Key used to translate the "remove rows" text of the table component.
 */
export declare const I18N_TABLE_REMOVE_ROWS_KEY = "BS_TABLE_REMOVE_ROWS";
/**
 * Key used to translate the "no rows" text of the table component.
 */
export declare const I18N_TABLE_NO_ROWS_KEY = "BS_TABLE_NO_ROWS";
declare const TableComponent_base: typeof TableController & (new (...args: any[]) => FieldComponentCommon);
export declare class TableComponent extends TableComponent_base implements FieldComponentCommon {
    _addRowText: string;
    _removeRowsText: string;
    _noRowsText: string;
    rowHeight: number;
    maxVisibleRows: number;
    excessRows: number;
    headerTemplate: TemplateRef<any>;
    rowTemplate: TemplateRef<any>;
    noRowsTemplate: TemplateRef<any>;
    _headerTableContainer: ElementRef;
    _bodyTableContainer: ElementRef;
    _virtualScroll: VirtualScrollComponent;
    protected _tableHeaderController: TableHeaderComponent | null;
    protected _selectedRows: Map<number, boolean>;
    protected _lastSelectedIndex: number | null;
    protected _disposeOnParentFormActivate: () => void;
    protected _disposeScroll: () => void;
    readonly addRowText: string;
    readonly removeRowsText: string;
    readonly noRowsText: string;
    readonly _tableActions: BsActionsMenuAction[];
    numberOfColumns(includeScrollbarColumn: boolean): number | null;
    tableMinWidth(includeScrollbarColumn: boolean): number | null;
    tableMaxWidth(includeScrollbarColumn: boolean): number | null;
    columnWidths(includeScrollbarColumn: boolean): string[];
    readonly verticalScrollbarWidth: number;
    readonly isEditable: boolean;
    readonly numberOfRowsSelected: number;
    readonly allRowsSelected: boolean;
    readonly noRowsSelected: boolean;
    getRowSelectedStatus(index: number): boolean;
    pushRow(): void;
    setRowSelectedStatus(index: number, selectedStatus: boolean): void;
    setRowSelectedStatusFromLastSelected(index: number, selectedStatus: boolean): void;
    unselectAllRows(): void;
    setAllRowsSelectedStatus(selectedStatus: boolean): void;
    toggleAllRowsSelectedStatus(): void;
    removeSelectedRows(): void;
    _onClickRemoveRows(): void;
    _onClickNewRow(): void;
    protected lfOnComponentInit(): void;
    protected lfAfterComponentViewInit(): void;
    protected lfOnComponentDestroy(): void;
}
