import { I18nService, RouterService, StorageService } from '@lightweightform/core';
import { ValidationError } from '@lightweightform/storage';
import { MarkdownService } from 'ngx-markdown';
export declare const I18N_VALIDATIONS_KEY = "LF_VALIDATIONS";
/**
 * Service used to format validation messages' to HTML messages
 */
export declare class ValidationMessagesService {
    protected _i18nService: I18nService;
    protected _routerService: RouterService;
    protected _storageService: StorageService;
    protected _markdownService: MarkdownService;
    constructor(_i18nService: I18nService, _routerService: RouterService, _storageService: StorageService, _markdownService: MarkdownService);
    /**
     * Formats a validation error message assuming the Markdown standard
     * specification. Applies some pre processors, such as:
     * - labelLink pre-processor: converts a tag with format "@${path}@" to a
     * hyperlink to the given path and a message specified in that path's
     * component.
     * @param path Path for the value which contains the error.
     * @param validationError Validation error with the preformatted message.
     * @returns Formatted message.
     */
    formatMessage(path: string, validationError: ValidationError): string;
    /**
     * Gets the label associated to the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    getLabel(path: string): string;
    protected _parseMD(message: string): string;
    protected _applyPreProcessors(message: string): string;
    protected _preProcessorLabelLinks(message: string): string;
}
